summaryrefslogtreecommitdiff
path: root/sw/source/filter/writer/wrt_fn.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/filter/writer/wrt_fn.cxx')
-rw-r--r--sw/source/filter/writer/wrt_fn.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/source/filter/writer/wrt_fn.cxx b/sw/source/filter/writer/wrt_fn.cxx
index 979a3cc1bfb9..de5a7c17e1bc 100644
--- a/sw/source/filter/writer/wrt_fn.cxx
+++ b/sw/source/filter/writer/wrt_fn.cxx
@@ -86,8 +86,8 @@ Writer& Out_SfxItemSet( const SwAttrFnTab pTab, Writer& rWrt,
Writer& Out( const SwNodeFnTab pTab, SwNode& rNode, Writer & rWrt )
{
- // It must be a CntntNode!
- SwCntntNode * pCNd = rNode.GetCntntNode();
+ // It must be a ContentNode!
+ SwContentNode * pCNd = rNode.GetContentNode();
if( !pCNd )
return rWrt;